[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# MultiModal Tree of Thoughts
Multi-Modal Foundation Model -> Deepfloyd iF or stable diffusion -> mmllm -> if

The objective is to implement DALLE-3 where given an input task to generate an image => its fed and enriched by the multimodal llm => passed into image generation



# Appreciation
* Lucidrains
* Agorians


# Install
`pip install mm-tot`

# Usage



# Architecture

# Todo


# License
MIT

